@@ -1,6 +1,6 @@
 package Moose::Meta::Attribute::Native;
 
-our $VERSION   = '0.93_03';
+our $VERSION   = '0.90';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -216,7 +216,9 @@ Common methods for code references.
 
 =head1 BUGS
 
-See L<Moose/BUGS> for details on reporting bugs.
+All complex software has bugs lurking in it, and this module is no
+exception. If you find a bug please either email me, or add the bug
+to cpan-RT.
 
 =head1 AUTHOR
 
@@ -248,10 +250,6 @@ Evan Carroll
 
 Jesse (doy) Luehrs
 
-Jay Hannah
-
-Robert Buels
-
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2007-2009 by Infinity Interactive, Inc.
