@@ -1,13 +1,13 @@
 package Moose::Meta::Attribute::Native::MethodProvider::Code;
 use Moose::Role;
 
-our $VERSION   = '0.93_03';
+our $VERSION   = '0.90';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub execute : method {
     my ( $attr, $reader, $writer ) = @_;
-    return sub { my ($self, @args) = @_; $reader->($self)->(@args) };
+    return sub { $reader->(@_)->(@_) };
 }
 
 no Moose::Role;
@@ -38,7 +38,9 @@ documentation on what methods are provided.
 
 =head1 BUGS
 
-See L<Moose/BUGS> for details on reporting bugs.
+All complex software has bugs lurking in it, and this module is no
+exception. If you find a bug please either email me, or add the bug
+to cpan-RT.
 
 =head1 AUTHOR
 
