@@ -3,7 +3,7 @@ package Moose::Meta::Attribute::Native::Trait;
 use Moose::Role;
 use Moose::Util::TypeConstraints;
 
-our $VERSION   = '0.93_03';
+our $VERSION   = '0.90';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -34,6 +34,9 @@ has 'method_constructors' => (
     },
 );
 
+has '+default'         => ( required => 1 );
+has '+type_constraint' => ( required => 1 );
+
 # methods called prior to instantiation
 
 before '_process_options' => sub {
@@ -139,11 +142,9 @@ Moose::Meta::Attribute::Native::Trait - Base role for helpers
 
 =head1 BUGS
 
-See L<Moose/BUGS> for details on reporting bugs.
-
-=head1 SEE ALSO
-
-Documentation for Moose native traits starts at L<Moose::Meta::Attribute Native>
+All complex software has bugs lurking in it, and this module is no
+exception. If you find a bug please either email me, or add the bug
+to cpan-RT.
 
 =head1 AUTHORS
 
