@@ -2,7 +2,7 @@ package Moose::Meta::Attribute::Native::Trait::Bool;
 use Moose::Role;
 use Moose::Meta::Attribute::Native::MethodProvider::Bool;
 
-our $VERSION = '0.93_03';
+our $VERSION = '0.90';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -11,6 +11,9 @@ with 'Moose::Meta::Attribute::Native::Trait';
 sub _default_is  { 'rw' }
 sub _helper_type { 'Bool' }
 
+# NOTE: we don't use the method provider for this module since many of
+# the names of the provided methods would conflict with keywords - SL
+
 has 'method_provider' => (
     is        => 'ro',
     isa       => 'ClassName',
@@ -98,7 +101,9 @@ Equivalent of 'not C<$value>'.
 
 =head1 BUGS
 
-See L<Moose/BUGS> for details on reporting bugs.
+All complex software has bugs lurking in it, and this module is no
+exception. If you find a bug please either email me, or add the bug
+to cpan-RT.
 
 =head1 AUTHOR
 
