@@ -11,7 +11,7 @@ use List::Util qw( first );
 use List::MoreUtils qw( any all uniq first_index );
 use Scalar::Util 'weaken', 'blessed';
 
-our $VERSION   = '0.89';
+our $VERSION   = '0.90';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -233,7 +233,7 @@ sub superclasses {
     foreach my $super (@supers) {
         Class::MOP::load_class($super);
         my $meta = Class::MOP::class_of($super);
-        Moose->throw_error("You cannot inherit from a Moose Role ($super)")
+        $self->throw_error("You cannot inherit from a Moose Role ($super)")
             if $meta && $meta->isa('Moose::Meta::Role')
     }
     return $self->SUPER::superclasses(@supers);
@@ -343,7 +343,7 @@ sub _superclass_meta_is_compatible {
 
     my $super_meta_name
         = $super_meta->is_immutable
-        ? $super_meta->get_mutable_metaclass_name
+        ? $super_meta->_get_mutable_metaclass_name
         : ref($super_meta);
 
     return 1
@@ -367,7 +367,7 @@ sub _reconcile_with_superclass_meta {
 
     my $super_meta_name
         = $super_meta->is_immutable
-        ? $super_meta->get_mutable_metaclass_name
+        ? $super_meta->_get_mutable_metaclass_name
         : ref($super_meta);
 
     my $self_metaclass = ref $self;
@@ -672,8 +672,9 @@ These all default to the appropriate Moose class.
 =item B<< Moose::Meta::Class->create($package_name, %options) >>
 
 This overrides the parent's method in order to accept a C<roles>
-option. This should be an array reference containing one more roles
-that the class does, each optionally followed by a hashref of options.
+option. This should be an array reference containing roles
+that the class does, each optionally followed by a hashref of options
+(C<-excludes> and C<-alias>).
 
   my $metaclass = Moose::Meta::Class->create( 'New::Class', roles => [...] );
 
