@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.89';
+our $VERSION   = '0.90';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -36,6 +36,13 @@ sub new {
         || confess
         'You must supply a delegate_to_method which is a method name or a CODE reference';
 
+    exists $options{curried_arguments}
+        || ( $options{curried_arguments} = [] );
+
+    ( $options{curried_arguments} &&
+        ( 'ARRAY' eq ref $options{curried_arguments} ) )
+        || confess 'You must supply a curried_arguments which is an ARRAY reference';
+
     my $self = $class->_new( \%options );
 
     weaken( $self->{'attribute'} );
@@ -52,6 +59,8 @@ sub _new {
     return bless $options, $class;
 }
 
+sub curried_arguments { (shift)->{'curried_arguments'} }
+
 sub associated_attribute { (shift)->{'attribute'} }
 
 sub delegate_to_method { (shift)->{'delegate_to_method'} }
@@ -95,17 +104,29 @@ sub _initialize_body {
                 object      => $instance
             );
         }
-
-        $proxy->$method_to_call(@_);
+        my @args = (@{ $self->curried_arguments }, @_);
+        $proxy->$method_to_call(@args);
     };
 }
 
 sub _get_delegate_accessor {
     my $self = shift;
+    my $attr = $self->associated_attribute;
 
-    my $accessor = $self->associated_attribute->get_read_method_ref;
+    # NOTE:
+    # always use a named method when
+    # possible, if you use the method
+    # ref and there are modifiers on
+    # the accessors then it will not
+    # pick up the modifiers too. Only
+    # the named method will assure that
+    # we also have any modifiers run.
+    # - SL
+    my $accessor = $attr->has_read_method
+        ? $attr->get_read_method
+        : $attr->get_read_method_ref;
 
-    $accessor = $accessor->body if blessed $accessor;
+    $accessor = $accessor->body if Scalar::Util::blessed $accessor;
 
     return $accessor;
 }
@@ -145,12 +166,21 @@ accessor is being generated for. This options is B<required>.
 The method in the associated attribute's value to which we
 delegate. This can be either a method name or a code reference.
 
+=item I<curried_arguments>
+
+An array reference of arguments that will be prepended to the argument list for
+any call to the delegating method.
+
 =back
 
 =item B<< $metamethod->associated_attribute >>
 
 Returns the attribute associated with this method.
 
+=item B<< $metamethod->curried_arguments >>
+
+Return any curried arguments that will be passed to the delegated method.
+
 =item B<< $metamethod->delegate_to_method >>
 
 Returns the method to which this method delegates, as passed to the
